@@ -32,6 +32,7 @@ class Puppet::Application::Device < Puppet::Application
       :centrallogs => false,
       :setdest => false,
       :resource => false,
+      :facts => false,
       :target => nil,
       :to_yaml => false,
     }.each do |opt,val|
@@ -44,6 +45,7 @@ class Puppet::Application::Device < Puppet::Application
   option("--centrallogging")
   option("--debug","-d")
   option("--resource","-r")
+  option("--facts","-f")
   option("--to_yaml","-y")
   option("--verbose","-v")
 
@@ -83,7 +85,7 @@ puppet-device(8) -- #{summary}
 
 SYNOPSIS
 --------
-Retrieves catalogs from the Puppet master and applies them to remote devices. 
+Retrieves catalogs from the Puppet master and applies them to remote devices.
 
 This subcommand can be run manually; or periodically using cron,
 a scheduled task, or a similar tool.
@@ -93,7 +95,7 @@ USAGE
 -----
   puppet device [-d|--debug] [--detailed-exitcodes] [--deviceconfig <file>]
                 [-h|--help] [-l|--logdest syslog|<file>|console]
-                [-v|--verbose] [-w|--waitforcert <seconds>]
+                [-v|--verbose] [-w|--waitforcert <seconds>] [-f|--facts]
                 [-a|--apply <file>] [-r|--resource <type> [name]]
                 [-t|--target <device>] [--user=<user>] [-V|--version]
 
@@ -106,9 +108,9 @@ retrieve and apply catalogs, and store reports.
 
 USAGE NOTES
 -----------
-Devices managed by the puppet-device subcommand on a Puppet agent are 
-configured in device.conf, which is located at $confdir/device.conf by default, 
-and is configurable with the $deviceconfig setting. 
+Devices managed by the puppet-device subcommand on a Puppet agent are
+configured in device.conf, which is located at $confdir/device.conf by default,
+and is configurable with the $deviceconfig setting.
 
 The device.conf file is an INI-like file, with one section per device:
 
@@ -117,20 +119,20 @@ type <TYPE>
 url <URL>
 debug
 
-The section name specifies the certname of the device. 
+The section name specifies the certname of the device.
 
 The values for the type and url properties are specific to each type of device.
 
 The optional debug property specifies transport-level debugging,
 and is limited to telnet and ssh transports.
 
-See https://docs.puppet.com/puppet/latest/config_file_device.html for details.
+See https://puppet.com/docs/puppet/latest/config_file_device.html for details.
 
 
 OPTIONS
 -------
-Note that any setting that's valid in the configuration file is also a valid 
-long argument. For example, 'server' is a valid configuration parameter, so 
+Note that any setting that's valid in the configuration file is also a valid
+long argument. For example, 'server' is a valid configuration parameter, so
 you can specify '--server <servername>' as an argument.
 
 * --debug:
@@ -163,6 +165,9 @@ you can specify '--server <servername>' as an argument.
 * --apply:
   Apply a manifest against a remote target. Target must be specified.
 
+* --facts:
+  Displays the facts of a remote target. Target must be specified.
+
 * --resource:
   Displays a resource state as Puppet code, roughly equivalent to
   `puppet resource`.  Can be filterd by title. Requires --target be specified.
@@ -208,18 +213,14 @@ Licensed under the Apache 2.0 License
 
   def main
     if options[:resource] and !options[:target]
-      Puppet.err _("resource command requires target")
-      exit(1)
+      raise _("resource command requires target")
+    end
+    if options[:facts] and !options[:target]
+      raise _("facts command requires target")
     end
     unless options[:apply].nil?
-      if options[:target].nil?
-        Puppet.err _("missing argument: --target is required when using --apply")
-        exit(1)
-      end
-      unless File.file?(options[:apply])
-        Puppet.err _("%{file} does not exist, cannot apply") % { file: options[:apply] }
-        exit(1)
-      end
+      raise _("missing argument: --target is required when using --apply") if options[:target].nil?
+      raise _("%{file} does not exist, cannot apply") % { file: options[:apply] } unless File.file?(options[:apply])
     end
     vardir = Puppet[:vardir]
     confdir = Puppet[:confdir]
@@ -235,7 +236,7 @@ Licensed under the Apache 2.0 License
       end
       if devices.empty?
         if options[:target]
-          Puppet.err _("Target device / certificate '%{target}' not found in %{config}") % { target: options[:target], config: Puppet[:deviceconfig] }
+          raise _("Target device / certificate '%{target}' not found in %{config}") % { target: options[:target], config: Puppet[:deviceconfig] }
         else
           Puppet.err _("No device found in %{config}") % { config: Puppet[:deviceconfig] }
           exit(1)
@@ -260,9 +261,7 @@ Licensed under the Apache 2.0 License
           if options[:resource]
             type, name = parse_args(command_line.args)
             Puppet.info _("retrieving resource: %{resource} from %{target} at %{scheme}%{url_host}%{port}%{url_path}") % { resource: type, target: device.name, scheme: scheme, url_host: device_url.host, port: port, url_path: device_url.path }
-
             resources = find_resources(type, name)
-
             if options[:to_yaml]
               text = resources.map do |resource|
                 resource.prune_parameters(:parameters_to_include => @extra_params).to_hierayaml.force_encoding(Encoding.default_external)
@@ -274,14 +273,24 @@ Licensed under the Apache 2.0 License
               end.join("\n")
             end
             (puts text)
+            0
+          elsif options[:facts]
+            Puppet.info _("retrieving facts from %{target} at %{scheme}%{url_host}%{port}%{url_path}") % { resource: type, target: device.name, scheme: scheme, url_host: device_url.host, port: port, url_path: device_url.path }
+            remote_facts = Puppet::Node::Facts.indirection.find(name, :environment => env)
+            # Give a proper name to the facts
+            remote_facts.name = remote_facts.values['clientcert']
+            renderer = Puppet::Network::FormatHandler.format(:console)
+            puts renderer.render(remote_facts)
+            0
           elsif options[:apply]
+            # ensure we have a cache folder structure exists for the device
+            FileUtils.mkdir_p(Puppet[:statedir]) unless File.directory?(Puppet[:statedir])
             # avoid reporting to server
             Puppet::Transaction::Report.indirection.terminus_class = :yaml
             Puppet::Resource::Catalog.indirection.cache_class = nil
 
             require 'puppet/application/apply'
             begin
-
               Puppet[:node_terminus] = :plain
               Puppet[:catalog_terminus] = :compiler
               Puppet[:catalog_cache_terminus] = nil
@@ -353,26 +362,30 @@ Licensed under the Apache 2.0 License
 
   def setup
     setup_logs
+    if options[:apply] || options[:facts] || options[:resource]
+      Puppet::Util::Log.newdestination(:console)
+      Puppet.settings.use :main, :agent, :ssl
+    else
+      args[:Server] = Puppet[:server]
+      if options[:centrallogs]
+        logdest = args[:Server]
 
-    args[:Server] = Puppet[:server]
-    if options[:centrallogs]
-      logdest = args[:Server]
+        logdest += ":" + args[:Port] if args.include?(:Port)
+        Puppet::Util::Log.newdestination(logdest)
+      end
 
-      logdest += ":" + args[:Port] if args.include?(:Port)
-      Puppet::Util::Log.newdestination(logdest)
-    end
+      Puppet.settings.use :main, :agent, :device, :ssl
 
-    Puppet.settings.use :main, :agent, :device, :ssl
+      # We need to specify a ca location for all of the SSL-related
+      # indirected classes to work; in fingerprint mode we just need
+      # access to the local files and we don't need a ca.
+      Puppet::SSL::Host.ca_location = :remote
 
-    # We need to specify a ca location for all of the SSL-related
-    # indirected classes to work; in fingerprint mode we just need
-    # access to the local files and we don't need a ca.
-    Puppet::SSL::Host.ca_location = :remote
+      Puppet::Transaction::Report.indirection.terminus_class = :rest
 
-    Puppet::Transaction::Report.indirection.terminus_class = :rest
-
-    if Puppet[:catalog_cache_terminus]
-      Puppet::Resource::Catalog.indirection.cache_class = Puppet[:catalog_cache_terminus].intern
+      if Puppet[:catalog_cache_terminus]
+        Puppet::Resource::Catalog.indirection.cache_class = Puppet[:catalog_cache_terminus].intern
+      end
     end
   end
 end
