@@ -295,7 +295,7 @@ class Puppet::Node::Environment
   # @param forge_name [String] The module name
   # @return [Puppet::Module, nil] The module if found, else nil
   def module_by_forge_name(forge_name)
-    author, modname = forge_name.split('/')
+    _, modname = forge_name.split('/')
     found_mod = self.module(modname)
     found_mod and found_mod.forge_name == forge_name ?
       found_mod :
@@ -435,7 +435,7 @@ class Puppet::Node::Environment
 
   # Loads module translations for the current environment once for
   # the lifetime of the environment.
-  def use_text_domain
+  def with_text_domain
     return if Puppet[:disable_i18n]
 
     if @text_domain.nil?
@@ -445,6 +445,10 @@ class Puppet::Node::Environment
     else
       Puppet::GettextConfig.use_text_domain(@text_domain)
     end
+
+    yield
+  ensure
+    Puppet::GettextConfig.clear_text_domain
   end
 
   # Checks if a reparse is required (cache of files is stale).
