@@ -37,7 +37,7 @@ class Factory
     end
   end
 
-  attr_reader :model_class
+  attr_reader :model_class, :unfolded
 
   def [](key)
     @init_hash[key]
@@ -179,7 +179,8 @@ class Factory
   end
 
   def build_ConcatenatedString(o, args)
-    @init_hash['segments'] = args
+    # Strip empty segments
+    @init_hash['segments'] = args.reject { |arg| arg.model_class == LiteralString && arg['value'].empty? }
   end
 
   def build_HeredocExpression(o, name, expr)
@@ -213,8 +214,9 @@ class Factory
     @init_hash[KEY_VALUE] = v
   end
 
-  def build_LiteralHash(o, keyed_entries)
+  def build_LiteralHash(o, keyed_entries, unfolded)
     @init_hash['entries'] = keyed_entries
+    @unfolded = unfolded
   end
 
   def build_LiteralList(o, values)
@@ -310,6 +312,7 @@ class Factory
   def infer_Hash(o)
     @model_class = LiteralHash
     @init_hash['entries'] = o.sort_by { |k,_| k.to_s }.map { |k, v| Factory.new(KeyedEntry, Factory.infer(k), Factory.infer(v)) }
+    @unfolded = false
   end
 
   def f_build_body(body)
@@ -347,6 +350,14 @@ class Factory
     @init_hash['return_type'] = return_type unless return_type.nil?
   end
 
+  def build_PlanDefinition(o, name, parameters, body, return_type=nil)
+    @init_hash[KEY_PARAMETERS] = parameters
+    b = f_build_body(body)
+    @init_hash[KEY_BODY] = b unless b.nil?
+    @init_hash[KEY_NAME] = name
+    @init_hash['return_type'] = return_type unless return_type.nil?
+  end
+
   def build_CapabilityMapping(o, kind, component, capability, mappings)
     @init_hash['kind'] = kind
     @init_hash['component'] = component
@@ -442,10 +453,12 @@ class Factory
       #
       parent = type_expr['key']
       hash = type_expr['value']
-      unless parent['cased_value'] == 'Object'
+      pn = parent['cased_value']
+      unless pn == 'Object' || pn == 'TypeSet'
         hash['entries'] << Factory.KEY_ENTRY(Factory.QNAME('parent'), parent)
+        parent = Factory.QREF('Object')
       end
-      type_expr = Factory.QREF('Object').access([hash])
+      type_expr = parent.access([hash])
     elsif type_expr.model_class <= LiteralHash
       # LiteralHash is used for the form:
       #
@@ -703,7 +716,9 @@ class Factory
 
   def self.KEY_ENTRY(key, val);          new(KeyedEntry, key, val);                      end
 
-  def self.HASH(entries);                new(LiteralHash, entries);                      end
+  def self.HASH(entries);                new(LiteralHash, entries, false);               end
+
+  def self.HASH_UNFOLDED(entries);       new(LiteralHash, entries, true);                end
 
   def self.HEREDOC(name, expr);          new(HeredocExpression, name, expr);             end
 
@@ -823,6 +838,17 @@ class Factory
     new(ExportedQuery, query_expr)
   end
 
+  def self.ARGUMENTS(args, arg)
+    if !args.empty? && arg.model_class <= LiteralHash && arg.unfolded
+      last = args[args.size() - 1]
+      if last.model_class <= LiteralHash && last.unfolded
+        last['entries'].concat(arg['entries'])
+        return args
+      end
+    end
+    args.push(arg)
+  end
+
   def self.ATTRIBUTE_OP(name, op, expr)
     new(AttributeOperation, name, op, expr)
   end
@@ -907,6 +933,10 @@ class Factory
     new(Application, name, parameters, body)
   end
 
+  def self.PLAN(name, parameters, body)
+    new(PlanDefinition, name, parameters, body, nil)
+  end
+
   def self.FUNCTION(name, parameters, body, return_type)
     new(FunctionDefinition, name, parameters, body, return_type)
   end
