@@ -122,6 +122,13 @@ Puppet::Type.type(:augeas).provide(:augeas) do
           if delim == "'" || delim == "\""
             sc.getch
             argline << sc.scan(/([^\\#{delim}]|(\\.))*/)
+            # Unescape the delimiter so it's actually possible to have a
+            # literal delim inside the string. We only unescape the
+            # delimeter and not every backslash-escaped character so that
+            # things like escaped spaces '\ ' get passed through because
+            # Augeas needs to see them. If we unescaped them, too, users
+            # would be forced to double-escape them
+            argline.last.gsub!(/\\(#{delim})/, '\1')
             sc.getch
           else
             argline << sc.scan(/[^\s]+/)
@@ -168,7 +175,6 @@ Puppet::Type.type(:augeas).provide(:augeas) do
       glob_avail = !aug.match("/augeas/version/pathx/functions/glob").empty?
       opt_ctx = resource[:context].match("^/files/[^'\"\\[\\]]+$") if resource[:context]
 
-      restricted = false
       if resource[:incl]
         aug.set("/augeas/load/Xfm/lens", resource[:lens])
         aug.set("/augeas/load/Xfm/incl", resource[:incl])
@@ -220,7 +226,7 @@ Puppet::Type.type(:augeas).provide(:augeas) do
 
     #validate and tear apart the command
     fail (_("Invalid command: %{cmd}") % { cmd: cmd_array.join(" ") }) if cmd_array.length < 4
-    cmd = cmd_array.shift
+    _ = cmd_array.shift
     path = cmd_array.shift
     comparator = cmd_array.shift
     arg = cmd_array.join(" ")
@@ -251,7 +257,7 @@ Puppet::Type.type(:augeas).provide(:augeas) do
 
     #validate and tear apart the command
     fail(_("Invalid command: %{cmd}") % { cmd: cmd_array.join(" ") }) if cmd_array.length < 3
-    cmd = cmd_array.shift
+    _ = cmd_array.shift
     path = cmd_array.shift
 
     # Need to break apart the clause
@@ -299,7 +305,7 @@ Puppet::Type.type(:augeas).provide(:augeas) do
 
     #validate and tear apart the command
     fail(_("Invalid command: %{cmd}") % { cmd: cmd_array.join(" ") }) if cmd_array.length < 3
-    cmd = cmd_array.shift
+    _ = cmd_array.shift
     path = cmd_array.shift
 
     # Need to break apart the clause
