@@ -106,7 +106,7 @@ Puppet::Type.newtype(:augeas) do
     desc "The changes which should be applied to the filesystem. This
     can be a command or an array of commands. The following commands are supported:
 
-    * `set <PATH> <VALUE>` --- Sets the value `VALUE` at loction `PATH`
+    * `set <PATH> <VALUE>` --- Sets the value `VALUE` at location `PATH`
     * `setm <PATH> <SUB> <VALUE>` --- Sets multiple nodes (matching `SUB` relative to `PATH`) to `VALUE`
     * `rm <PATH>` --- Removes the node at location `PATH`
     * `remove <PATH>` --- Synonym for `rm`
@@ -137,7 +137,7 @@ Puppet::Type.newtype(:augeas) do
 
   newparam(:force) do
     desc "Optional command to force the augeas type to execute even if it thinks changes
-    will not be made. This does not overide the `onlyif` parameter."
+    will not be made. This does not override the `onlyif` parameter."
 
     defaultto false
   end
@@ -150,13 +150,13 @@ Puppet::Type.newtype(:augeas) do
   end
 
   newparam(:lens) do
-    desc "Use a specific lens, e.g. `Hosts.lns`. When this parameter is set, you
+    desc "Use a specific lens, such as `Hosts.lns`. When this parameter is set, you
       must also set the `incl` parameter to indicate which file to load.
       The Augeas documentation includes [a list of available lenses](http://augeas.net/stock_lenses.html)."
   end
 
   newparam(:incl) do
-    desc "Load only a specific file, e.g. `/etc/hosts`. This can greatly speed
+    desc "Load only a specific file, such as `/etc/hosts`. This can greatly speed
       up the execution the resource. When this parameter is set, you must also
       set the `lens` parameter to indicate which lens to use."
   end
@@ -164,7 +164,7 @@ Puppet::Type.newtype(:augeas) do
   validate do
     has_lens = !self[:lens].nil?
     has_incl = !self[:incl].nil?
-    self.fail "You must specify both the lens and incl parameters, or neither." if has_lens != has_incl
+    self.fail _("You must specify both the lens and incl parameters, or neither.") if has_lens != has_incl
   end
 
   newparam(:show_diff, :boolean => true, :parent => Puppet::Parameter::Boolean) do
@@ -188,11 +188,11 @@ Puppet::Type.newtype(:augeas) do
 
     # Make output a bit prettier
     def change_to_s(currentvalue, newvalue)
-      "executed successfully"
+      _("executed successfully")
     end
 
     # if the onlyif resource is provided, then the value is parsed.
-    # a return value of 0 will stop exection because it matches the
+    # a return value of 0 will stop execution because it matches the
     # default value.
     def retrieve
       if @resource.provider.need_to_run?()
