@@ -9,8 +9,8 @@ require 'puppet/parameter/boolean'
 module Puppet
   Type.newtype(:package) do
     @doc = "Manage packages.  There is a basic dichotomy in package
-      support right now:  Some package types (e.g., yum and apt) can
-      retrieve their own package files, while others (e.g., rpm and sun)
+      support right now:  Some package types (such as yum and apt) can
+      retrieve their own package files, while others (such as rpm and sun)
       cannot.  For those package formats that cannot retrieve their own files,
       you can use the `source` parameter to point to the correct file.
 
@@ -111,7 +111,7 @@ module Puppet
         begin
           provider.update
         rescue => detail
-          self.fail Puppet::Error, "Could not update: #{detail}", detail
+          self.fail Puppet::Error, _("Could not update: %{detail}") % { detail: detail }, detail
         end
 
         if current == :absent
@@ -125,7 +125,7 @@ module Puppet
         begin
           provider.install
         rescue => detail
-          self.fail Puppet::Error, "Could not update: #{detail}", detail
+          self.fail Puppet::Error, _("Could not update: %{detail}") % { detail: detail }, detail
         end
 
         if self.retrieve == :absent
@@ -160,7 +160,7 @@ module Puppet
                 @latest = provider.latest
                 @lateststamp = Time.now.to_i
               rescue => detail
-                error = Puppet::Error.new("Could not get latest version: #{detail}")
+                error = Puppet::Error.new(_("Could not get latest version: %{detail}") % { detail: detail })
                 error.set_backtrace(detail.backtrace)
                 raise error
               end
@@ -206,7 +206,7 @@ module Puppet
       # Provide a bit more information when logging upgrades.
       def should_to_s(newvalue = @should)
         if @latest
-          @latest.to_s
+          super(@latest)
         else
           super(newvalue)
         end
@@ -242,7 +242,7 @@ module Puppet
             name   => $ssl,
           }
 
-          . etc. .
+          ...
 
           $ssh = $operatingsystem ? {
             solaris => SMCossh,
@@ -260,7 +260,7 @@ module Puppet
 
       validate do |value|
         if !value.is_a?(String)
-          raise ArgumentError, "Name must be a String not #{value.class}"
+          raise ArgumentError, _("Name must be a String not %{klass}") % { klass: value.class }
         end
       end
     end
